=============================
django-excel-to-model
=============================

.. image:: https://badge.fury.io/py/django-excel-to-model.png
    :target: https://badge.fury.io/py/django-excel-to-model

.. image:: https://travis-ci.org/weijia/django-excel-to-model.png?branch=master
    :target: https://travis-ci.org/weijia/django-excel-to-model

Create model file from excel

Documentation
-------------

The full documentation is at https://django-excel-to-model.readthedocs.org.

Quickstart
----------

Install django-excel-to-model::

    pip install django-excel-to-model

Then use it in a project::

    import django_excel_to_model

Features
--------

* TODO

Running Tests
--------------

Does the code actually work?

::

    source <YOURVIRTUALENV>/bin/activate
    (myenv) $ pip install -r requirements-text.txt
    (myenv) $ python runtests.py

Credits
---------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-pypackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-pypackage`: https://github.com/pydanny/cookiecutter-djangopackage
